VmtInstance

Trait VmtInstance 

pub trait VmtInstance<T: 'static>: 'static + VmtLayout {
    const VTABLE: &'static Self::Layout<T>;
}
Provides compile-time virtual method table references for the concrete type T.

This trait is implemented on the vtable trait object, e.g. dyn MyVtable.

Required Associated Constants

const VTABLE: &'static Self::Layout<T>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors