pub unsafe trait VmtLayout: 'static {
type Layout<T: 'static>: 'static + Copy + Send + Sync;
}Expand description
Provides concrete virtual method table layouts for a vtable trait.
Safety
Implementing this trait manually does not currently require abiding by any safety invariants. However, this may change in future versions.
Required Associated Types
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.